define([
  'angular',
  'lodash',
  'jquery',
  'config',
  'kbn',
  'moment',
  './tsqueryCtrl',
],
function (angular, _, $, config, kbn, moment) {
  'use strict';

  var module = angular.module('grafana.services');

  module.factory('CdhDatasource', function($q, $http, templateSrv) {
    function CdhDatasource(datasource) {
      this.type = 'CdhDatasource';
      this.name = datasource.name;
      this.supportMetrics = true;
      //this.url = datasource.url;
      this.url = 'http://$GRAFANAURL/cdh';
      this.editorSrc = 'partials/query.editor.html';
    }

    CdhDatasource.prototype.query = function(options) {
      // Assumption:
      // Every tsquery metric expression has only one metric, and we get back one timeSeries element
      // used here: results.data.items[0].timeSeries
      var result_data = [];
      var promises = [];
      for (var i = 0; i < options.targets.length; i++) {
        var target = options.targets[i];
        if (!target.target || target.hide) {
          continue;
        }
        var req = {
          method: 'GET',
          url: this.url + '/timeseries?query='+encodeURIComponent(options.targets[i].target)
                        + '&' + 'contentType=application%2Fjson'
                        + '&' + 'from=' + kbn.parseDate(options.range.from).toJSON()
                        + '&' + 'to='   + kbn.parseDate(options.range.to).toJSON()
        };
        promises.push(
          $http(req).then(function(results) {
            console.log({CDH_API_results:results});
            results.data.items[0].timeSeries.forEach(function(timeSeries) {
              result_data.push({
                target: timeSeries.metadata.metricName,
                datapoints: _.map(timeSeries.data, function(datum) { return [datum.value, new Date(datum.timestamp).getTime()] })
              });
            });  // timeSeries.forEach
          })  // $http(req).then(function(results) {
        );  // promises.push(
      }  // for (i = 0; i < options.targets.length; i++) {

      return $q.all(promises).then(function () {
        console.log({query_result_data:result_data});
        return {data: result_data};
      });
    };

    return CdhDatasource;

  });
});
